#ifndef _cpuinfometer_h
#define _cpuinfometer_h


#include "cpuinfo.h"


bool getCpuinfo(Cpuinfo & cpuinfo);


#endif // _cpuinfometer_h
